@@ -8,21 +8,28 @@ ui <- fluidPage(  # Define UI for app that draws the bar chart
 
     sidebarPanel(  # Sidebar panel for inputs
 
-    selectInput(inputId = "myFill",
-                label = "fill",
-                choices = list(
-                  "colors", "darkred", "gray45", "gray75", "slategray3",
-                  "magenta3", "darkseagreen2", "purple",
-                  "reds", "rusts", "yellows",
-                  "olives", "greens", "emeralds", "turquoises",
-                  "aquas", "blues", "purples", "violets",
-                  "magentas", "grays")
+      selectInput(inputId = "myFill",
+                  label = "fill",
+                  selected = "lightsteelblue3",
+                  choices = list(
+                    `Individual Colors` = list(
+                      "lightsteelblue3", "darkred", "gray45", "gray75",
+                      "wheat3", "burlywood3", "burlywood4", "slategray3",
+                      "darkseagreen2", "seagreen4", "#90A5C3",
+                      "lightblue3", "sienna", "lavender", "lightsalmon",
+                      "lightcoral", "magenta3", "purple"),
+                    `Range of Colors` = list(
+                      "reds", "rusts", "yellows",
+                      "olives", "greens", "emeralds", "turquoises",
+                      "aquas", "blues", "purples", "violets",
+                      "magentas", "grays", "colors")
+                  )
       ),
 
       selectInput(inputId = "myColor",
                   label = "color",
                   choices = list("off", "darkgray", "black", "gold",
-                                 "steelblue", "darkred", "green3")
+                                 "steelblue", "darkred", "red", "green3")
       ),
 
       sliderInput(inputId = "myTrans",
@@ -47,7 +54,8 @@ ui <- fluidPage(  # Define UI for app that draws the bar chart
 
       selectInput(inputId = "myValuesColor",
                   label = "values_color",
-                  choices = list("white", "gray", "darkgray", "black")
+                  choices = list("white", "gray", "darkgray", "black",
+                                 "red", "green3")
       ),
 
 
